pyxmpp2.resolver.ThreadedResolver

Package pyxmpp2 :: Module resolver :: Class ThreadedResolver |
[hide private]

# Class ThreadedResolver

Threaded resolver implementation using the DNSPython `dns.resolver` module.

Nested Classes | [hide private]
Inherited from `interfaces.Resolver`: `__metaclass__`

Instance Methods | [hide private]
_make_resolver(self) Return the blocking resolver implementation that should be used by the resolver threads. |
Inherited from `ThreadedResolverBase`: `__init__`, `resolve_address`, `resolve_srv`, `stop` Inherited from `ThreadedResolverBase` (private): `_run`, `_start_thread` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
Inherited from `interfaces.Resolver`: `__abstractmethods__` Inherited from `interfaces.Resolver` (private): `_abc_cache`, `_abc_negative_cache`, `_abc_negative_cache_version`, `_abc_registry`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### _make_resolver(self) |
Return the blocking resolver implementation that should be used by the resolver threads. Overrides: ThreadedResolverBase._make_resolver (inherited documentation)